#
# spec file for package yast2-fonts
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yast2-fonts
Version:        4.1.0
Release:        1.2

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2

Requires:       fontconfig
Requires:       fonts-config >= 20150424
Requires:       yast2 >= 3.0.5
Requires:       yast2-ruby-bindings >= 1.2.0

BuildRequires:  update-desktop-files
BuildRequires:  yast2 >= 3.0.5
BuildRequires:  yast2-devtools >= 1.2.0
BuildRequires:  yast2-ruby-bindings >= 1.2.0
BuildRequires:  rubygem(yast-rake)
# extensions
BuildRequires:  font-specimen-devel
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  ruby-devel
# for testing
BuildRequires:  dejavu-fonts
BuildRequires:  fonts-config >= 20150424
BuildRequires:  rubygem(rspec)

Summary:        YaST2 - Fonts Configuration
License:        GPL-2.0-or-later
Group:          System/YaST
Url:            https://github.com/yast/yast-fonts

%description
Module for configuring X11 fonts able to select preferred font families
as well as set rendering algorithms to be used.


%prep
%setup -n %{name}-%{version}

%build
# build ruby bindings
rake compile

%install
rake install DESTDIR="%{buildroot}"
# install ruby bindings
mkdir -p  %{buildroot}%{_libdir}/ruby/vendor_ruby/%{rb_ver}/%{rb_arch}/yast
for ext in `ls src/ext`; do
  install -m 755 src/ext/$ext/$ext.so %{buildroot}%{_libdir}/ruby/vendor_ruby/%{rb_ver}/%{rb_arch}/yast
done

%check
rake test:unit

%files
%defattr(-,root,root)
%dir %{yast_libdir}/fonts
%{yast_libdir}/fonts/*.rb
%{_libdir}/ruby/vendor_ruby/%{rb_ver}/%{rb_arch}/yast/*.so
%{yast_clientdir}/fonts.rb
%{yast_desktopdir}/fonts.desktop
%{yast_scrconfdir}/*.scr
%dir %{yast_docdir}
%doc %{yast_docdir}/CONTRIBUTING.md
%license COPYING
%doc %{yast_docdir}/README.md
%doc %{yast_docdir}/README.subpixel-patents
%{yast_icondir}

%changelog
* Sat Nov 24 2018 Stasiek Michalski <hellcp@mailbox.org>
- Provide icon with module (boo#1109310)
- 4.1.0
* Tue Nov 13 2018 fraser_bell@opensuse.org
- Change Desktop File wording style to look more consistent with
  other YaST modules
- bnc#1084864 - Bump Version and change log
- 4.0.2
* Sun Nov 11 2018 fraser_bell@opensuse.org
- Changed Desktop File fonts.desktop Name= from Fonts to
  System-Wide Fonts to satisfy [Bug 1084864] YaST module names are
  too similar to some desktop environment configuration modules
- Fix typos in User Help Dialogues, improve readability
* Wed Oct 17 2018 schubi@suse.de
- Added %%license tag in spec file.
  Needed to build fix for bnc#1087957 again.
- 4.0.1
* Fri Apr  6 2018 mfilka@suse.com
- bnc#1087957 - version bump
- 4.0.0
* Fri Mar  2 2018 antoine.belvire@opensuse.org
- Fix paragraph end tag (boo#1084791).
- 3.2.1
* Wed Nov  2 2016 pgajdos@suse.com
- fix regression introduced in 3.1.17: installed families table
  was not filled correctly
- add UTF-8 encoding to ruby string [bsc#1006510]
- 3.2.0
* Wed Sep 14 2016 pgajdos@suse.com
- comma and the rest of family string is ignored [bsc#998300]
- 3.1.17
* Tue Oct  6 2015 pgajdos@suse.com
- require fileutils before use
- 3.1.16
* Mon May 25 2015 pgajdos@suse.com
- initialize_embeddedbitmaps_widget have parameter optional
  [bnc#932186]
- 3.1.15
* Fri May  8 2015 ancor@suse.com
- more flexible dependency in package specification (bsc#929899)
- 3.1.14
* Tue Apr 28 2015 pgajdos@suse.com
- user mode
- 3.1.13
* Wed Dec 10 2014 pgajdos@suse.com
- use _raw_ default fontconfig plus rendring/family list changes
  that happened in the dialog on the top for displaying specimens
- 3.1.12
* Tue Dec  9 2014 pgajdos@suse.com
- family add dialog improvements
- several bug fixes
- test improvements
- 3.1.11
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
- 3.1.10
* Thu Nov 13 2014 pgajdos@suse.com
- add match preview tab
- 3.1.9
* Fri Oct 24 2014 pgajdos@suse.com
- fix internal error
- 3.1.8
* Fri Oct 24 2014 pgajdos@suse.com
- implemented some suggestions for tests
- 3.1.7
* Thu Oct 23 2014 pgajdos@suse.com
- rewrite Rakefile again and employ chrooted test read and write
  (thanks to jreidinger)
- 3.1.6
* Thu Oct 23 2014 pgajdos@suse.com
- better lcdfilter usage warning
- 3.1.5
* Thu Oct 23 2014 pgajdos@suse.com
- do not crash on sysconfig file without some of PREFER_*_FAMILIES
  variables
- error out before attempt to write sysconfig file and run
  fonts-config as non-root user
- 3.1.4
* Wed Oct 22 2014 pgajdos@suse.com
- warn when installed FreeType2 do not support subpixel rendering
- 3.1.3
* Mon Oct 20 2014 pgajdos@suse.com
- added subpixel rendering profile
- 3.1.2
* Thu Aug 21 2014 pgajdos@suse.com
- added test suite
- 3.1.1
* Wed Jun 11 2014 pgajdos@suse.com
- initial version 3.1.0
